/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: nederlands.c,v 1.4 2007/04/08 15:33:37 itix Exp $

    Desc: nederlands.language description file.
    Lang: english
*/

/*  Language file for the Dutch language. */

#include <exec/types.h>
#include <aros/system.h>
#include <exec/resident.h>
#include <exec/libraries.h>
#include <libraries/locale.h>
#include <dos/dos.h>

#include <proto/exec.h>
#include <aros/libcall.h>

#include <aros/debug.h>

#define LANGSTR     "nederlands" /* String version of above */
#define LANGVER     51          /* Version number of language */
#define LANGREV     0           /* Revision number of language */
#define LANGTAG     "\0$VER: nederlands.language 51.0 (08.04.2007)"

STRPTR AROS_SLIB_ENTRY(getlangstring,language)();

/* ----------------------------------------------------------------------- */

/* Bit masks for locale .language functions. Only implement GetString() */
#define LF_GetLangStr       (1L << 3)
#define LF_GetLangStrU      (1L << 17)

#define LF_MASK             (LF_GetLangStr | LF_GetLangStrU)

/* Arrays for French character type/conversion */
extern const STRPTR __dutch_strings[];
extern const CONST_WSTRPTR __dutch_stringsu[];

/* -------------------------------------------------------------------------
   Library definition, you should not need to change any of this.
 ------------------------------------------------------------------------- */

struct Language
{
    struct Library library;
    struct ExecBase *sysbase;
    BPTR seglist;
};

extern const UBYTE name[];
extern const UBYTE version[];
extern const APTR inittabl[4];
extern void *const functable[];
extern struct Language *AROS_SLIB_ENTRY(init,language)();
extern struct Language *AROS_SLIB_ENTRY(open,language)();
extern BPTR AROS_SLIB_ENTRY(close,language)();
extern BPTR AROS_SLIB_ENTRY(expunge,language)();
extern int AROS_SLIB_ENTRY(null,language)();
extern ULONG AROS_SLIB_ENTRY(mask,language)();
extern const char end;

int entry(void)
{
    return -1;
}

const struct Resident languageTag =
{
    RTC_MATCHWORD,
    (struct Resident *)&languageTag,
    (APTR)&languageTag + 1,
#ifdef __MORPHOS__
    RTF_PPC | RTF_AUTOINIT,
#else
    RTF_AUTOINIT,
#endif
    LANGVER,
    NT_LIBRARY,
    -120,
    (STRPTR)name,
    (STRPTR)&version[7],
    (ULONG *)inittabl
};

const UBYTE name[]=LANGSTR ".language";
const UBYTE version[]=LANGTAG;

const APTR inittabl[4] =
{
    (APTR)sizeof(struct Language),
    (APTR)functable,
    (APTR)NULL,
    &AROS_SLIB_ENTRY(init,language)
};

struct ExecBase *mySysBase;

#ifdef __MORPHOS__
struct Language *LIB_init(struct Language *language, BPTR segList, struct ExecBase *SysBase)
#else
AROS_LH2(struct Language *, init,
    AROS_LHA(struct Language *, language, D0),
    AROS_LHA(BPTR,             segList, A0),
    struct ExecBase *, SysBase, 0, language)
#endif
{
    AROS_LIBFUNC_INIT

    /*
	You could just as easily do this bit as the InitResident()
	datatable, however this works just as well.
    */
    language->library.lib_Node.ln_Type = NT_LIBRARY;
    language->library.lib_Node.ln_Pri = -120;
    (const UBYTE *)language->library.lib_Node.ln_Name = name;
    language->library.lib_Flags = LIBF_SUMUSED | LIBF_CHANGED;
    language->library.lib_Version = LANGVER;
    language->library.lib_Revision = LANGREV;
    (const UBYTE *)language->library.lib_IdString = &version[7];

    language->seglist = segList;
    language->sysbase = SysBase;
    mySysBase = SysBase;

    /*
	Although it is unlikely, you would return NULL if you for some
	unknown reason couldn't open.
    */
//    bug("GetLangStr: Loaded at address %p\n", &AROS_SLIB_ENTRY(getlangstring,language));
    return language;

#ifndef __MORPHOS__
    AROS_LIBFUNC_EXIT
#endif
}

#define SysBase language->sysbase

AROS_LH1(struct Language *, open,
    AROS_LHA(ULONG, version, D0),
    struct Language *, language, 1, language)
{
    AROS_LIBFUNC_INIT
    language->library.lib_OpenCnt++;
    language->library.lib_Flags &= ~LIBF_DELEXP;

    /* Again return NULL if you could not open */
    return language;

    AROS_LIBFUNC_EXIT
}

AROS_LH0(BPTR, close, struct Language *, language, 2, language)
{
    AROS_LIBFUNC_INIT

    if(! --language->library.lib_OpenCnt)
    {
	/* Delayed expunge pending? */
	if(language->library.lib_Flags & LIBF_DELEXP)
	{
	    /* Yes, expunge the library */
	    return AROS_LC0(BPTR, expunge, struct Language *, language, 3, language);
	}
    }
    return NULL;
    AROS_LIBFUNC_EXIT
}

AROS_LH0(BPTR, expunge, struct Language *, language, 3, language)
{
    AROS_LIBFUNC_INIT

    BPTR ret;
    if(language->library.lib_OpenCnt)
    {
	/* Can't expunge, we are still open */
	language->library.lib_Flags |= LIBF_DELEXP;
	return 0;
    }

    REMOVE(&language->library.lib_Node);
    ret = language->seglist;

    FreeMem((UBYTE *)language - language->library.lib_NegSize,
	    language->library.lib_PosSize + language->library.lib_NegSize);

    return ret;

    AROS_LIBFUNC_EXIT
}

AROS_LH0I(int, null, struct Language *, language, 4, language)
{
    AROS_LIBFUNC_INIT

    return 0;

    AROS_LIBFUNC_EXIT
}

/* ------------------------------------------------------------------------
   Language specific functions
 ------------------------------------------------------------------------ */

#undef SysBase
#define SysBase	mySysBase

/* ULONG LanguageMask():
    This function is to inform locale.library what functions it should
    use from this library. This is done by returning a bitmask containing
    1's for functions to use, and 0's for functions to ignore.

    Unused bits MUST be 0 for future compatibility.
*/
AROS_LH0(ULONG, mask, struct Language *, language, 5, language)
{
    AROS_LIBFUNC_INIT

    return ( LF_MASK );

    AROS_LIBFUNC_EXIT
}

/* STRPTR GetLangString(ULONG num): Language function 3
    This function is called by GetLocaleStr() and should return
    the string matching the string id passed in as num.
*/
AROS_LH1(STRPTR, getlangstring,
    AROS_LHA(ULONG, id, D0),
    struct LocaleBase *, LocaleBase, 9, language)
{
    AROS_LIBFUNC_INIT

    //kprintf("\nWe have got to getlangstring\n");

    if(id < MAXSTRMSG)
	return __dutch_strings[id];
    else
	return NULL;

    AROS_LIBFUNC_EXIT
}

CONST_WSTRPTR LIB_getlangstringu(ULONG id, struct LocaleBase *LocaleBase)
{
    if (id < MAXSTRMSG)
        return __dutch_stringsu[id];
    else
        return NULL;
}

/* -----------------------------------------------------------------------
   Library function table - you will need to alter this
   I have this right here at the end of the library so that I do not
   have to have prototypes for the functions. Although you could do that.
   ----------------------------------------------------------------------- */

void *const functable[] =
{
    (void *const) FUNCARRAY_BEGIN,
    (void *)FUNCARRAY_32BIT_NATIVE,
    &AROS_SLIB_ENTRY(open,language),
    &AROS_SLIB_ENTRY(close,language),
    &AROS_SLIB_ENTRY(expunge,language),
    &AROS_SLIB_ENTRY(null,language),
    &AROS_SLIB_ENTRY(mask,language),

    /* Note, shorter function table, as only getlangstring is used */

    /* 0 - 3 */
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),    
    &AROS_SLIB_ENTRY(getlangstring, language),

    /* 4 - 16 */
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    &AROS_SLIB_ENTRY(null, language),
    (void *)-1,

	/* 17 */
	(void *) FUNCARRAY_32BIT_SYSTEMV,
	&LIB_getlangstringu,
	(void *)-1L,

    (void *const) FUNCARRAY_END
};

/*
    Note how only the required data structures are kept...

    This is the list of strings. It is an array of pointers to strings,
    although how it is laid out is implementation dependant.
*/
static const STRPTR __dutch_strings[] =
{
    /* A blank string */
    "",

    /*  The days of the week. Starts with the first day of the week.
	In English this would be Sunday, this depends upon the settings
	of Locale->CalendarType.
    */
    "Zondag", "Maandag", "Dinsdag", "Woensdag", "Donderdag",
    "Vrijdag", "Zaterdag",

    /* Abbreviated days of the week */
    "Zo", "Ma", "Di", "Wo", "Do", "Vr", "Za",

    /* Months of the year */
    "Januari", "Februari", "Maart",
    "April", "Mei", "Juni",
    "Juli", "Augustus", "September",
    "Oktober", "November", "December",

    /* Abbreviated months of the year */
    "Jan", "Feb", "Maa", "Apr", "Mei", "Jun",
    "Jul", "Aug", "Sep", "Okt", "Nov", "Dec",

    "Ja", /* Yes, affirmative response */
    "Nee", /* No/negative response */

    /* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */
    "VM", "NM",

    /* Soft and hard hyphens */
    "-", "-",

    /* Open and close quotes */
    "\"", "\"",

    /* Days: But not actual day names
       Yesterday - the day before the current
       Today - the current day
       Tomorrow - the next day
       Future.
    */
    "Gisteren", "Vandaag", "Morgen", "Toekomst"
};

static const CONST_WSTRPTR __dutch_stringsu[] =
{
    /* A blank string */
    (CONST_WSTRPTR)L"",

    /*  The days of the week. Starts with the first day of the week.
	In English this would be Sunday, this depends upon the settings
	of Locale->CalendarType.
    */
    (CONST_WSTRPTR)L"Zondag", (CONST_WSTRPTR)L"Maandag", (CONST_WSTRPTR)L"Dinsdag", (CONST_WSTRPTR)L"Woensdag", (CONST_WSTRPTR)L"Donderdag",
    (CONST_WSTRPTR)L"Vrijdag", (CONST_WSTRPTR)L"Zaterdag",

    /* Abbreviated days of the week */
    (CONST_WSTRPTR)L"Zo", (CONST_WSTRPTR)L"Ma", (CONST_WSTRPTR)L"Di", (CONST_WSTRPTR)L"Wo", (CONST_WSTRPTR)L"Do", (CONST_WSTRPTR)L"Vr", (CONST_WSTRPTR)L"Za",

    /* Months of the year */
    (CONST_WSTRPTR)L"Januari", (CONST_WSTRPTR)L"Februari", (CONST_WSTRPTR)L"Maart",
    (CONST_WSTRPTR)L"April", (CONST_WSTRPTR)L"Mei", (CONST_WSTRPTR)L"Juni",
    (CONST_WSTRPTR)L"Juli", (CONST_WSTRPTR)L"Augustus", (CONST_WSTRPTR)L"September",
    (CONST_WSTRPTR)L"Oktober", (CONST_WSTRPTR)L"November", (CONST_WSTRPTR)L"December",

    /* Abbreviated months of the year */
    (CONST_WSTRPTR)L"Jan", (CONST_WSTRPTR)L"Feb", (CONST_WSTRPTR)L"Maa", (CONST_WSTRPTR)L"Apr", (CONST_WSTRPTR)L"Mei", (CONST_WSTRPTR)L"Jun",
    (CONST_WSTRPTR)L"Jul", (CONST_WSTRPTR)L"Aug", (CONST_WSTRPTR)L"Sep", (CONST_WSTRPTR)L"Okt", (CONST_WSTRPTR)L"Nov", (CONST_WSTRPTR)L"Dec",

    (CONST_WSTRPTR)L"Ja", /* Yes, affirmative response */
    (CONST_WSTRPTR)L"Nee", /* No/negative response */

    /* AM/PM strings AM 0000 -> 1159, PM 1200 -> 2359 */
    (CONST_WSTRPTR)L"VM", (CONST_WSTRPTR)L"NM",

    /* Soft and hard hyphens */
    (CONST_WSTRPTR)L"-", (CONST_WSTRPTR)L"-",

    /* Open and close quotes */
    (CONST_WSTRPTR)L"\"", (CONST_WSTRPTR)L"\"",

    /* Days: But not actual day names
       Yesterday - the day before the current
       Today - the current day
       Tomorrow - the next day
       Future.
    */
    (CONST_WSTRPTR)L"Gisteren", (CONST_WSTRPTR)L"Vandaag", (CONST_WSTRPTR)L"Morgen", (CONST_WSTRPTR)L"Toekomst"
};
